/*
 * @file Member ID Definition of Group IPV6
 *
 * Moderator: Jon
 * Group ID: 0x00900000/0x80900000
 */

#ifndef _CSID_IPV6_H
#define _CSID_IPV6_H

#include "csid_gid.h"

#define _CFG_IPV6(x)					(CSID_GIDC_IPV6|(x))
#define _STA_IPV6(x)					(CSID_GIDS_IPV6|(x))

/* Extra Definitions */

#define IPV6_CONNECTION_TYPE_LINK_LOCAL     0x0000
#define IPV6_CONNECTION_TYPE_FIXED          0x0100
#define IPV6_CONNECTION_TYPE_DHCPV6         0x0200
#define IPV6_CONNECTION_TYPE_PPPOE          0x0300
#define IPV6_CONNECTION_TYPE_6TO4           0x0400
#define IPV6_CONNECTION_TYPE_6IN4		    0x0500

#define IPV6_AUTO_CONFIG_DISABLE			0x00
#define IPV6_AUTO_CONFIG_STATEFUL			0x01
#define IPV6_AUTO_CONFIG_STATELESS			0x02


/* Configuration Items */

#define CSID_C_IPV6_ENABLE						_CFG_IPV6(0x0000) //T=u32, D=0, ipv6 enable
#define CSID_C_IPV6_CONNECTION_TYPE			    _CFG_IPV6(0x0001) //T=u32, connection type
#define CSID_C_IPV6_AUTO_CONFIG					_CFG_IPV6(0x0002) //T=u32, autoconfiguration

/* [lan interface] */
#define CSID_C_IPV6_LAN_IF_LL_IP		        _CFG_IPV6(0x0010) //T=str, lan link-local address
#define CSID_C_IPV6_LAN_IF_IP                   _CFG_IPV6(0x0011) //T=str, lan address
#define CSID_C_IPV6_LAN_IF_PREFIX_LEN           _CFG_IPV6(0x0012) //T=u32, D=64,lan if prefix

/* [fix] */
#define CSID_C_IPV6_FIX_IF_IP					_CFG_IPV6(0x0100) //T=str, static wan ip
#define CSID_C_IPV6_FIX_IF_PREFIX_LEN   		_CFG_IPV6(0x0101) //T=u32, static prefix length
#define CSID_C_IPV6_FIX_IF_GW					_CFG_IPV6(0x0102) //T=str, static gateway
#define CSID_C_IPV6_FIX_IF_PRIDNS				_CFG_IPV6(0x0103) //T=str, static primary dns address
#define CSID_C_IPV6_FIX_IF_SECDNS				_CFG_IPV6(0x0104) //T=str, static secondary dns address
#define CSID_C_IPV6_FIX_MTU						_CFG_IPV6(0x0105) //T=u32, static mtu

/* [DHCPv6c] */

/* [pppoe] */
#define CSID_C_IPV6_PPPOE_USER 					_CFG_IPV6(0x0300)	//T=str, pppoe user name
#define CSID_C_IPV6_PPPOE_PASSWORD 				_CFG_IPV6(0x0301)   //T=str, pppoe password
#define CSID_C_IPV6_PPPOE_SERVICENAME			_CFG_IPV6(0x0302)   //T=str, pppoe service name
#define CSID_C_IPV6_PPPOE_MTU  					_CFG_IPV6(0x0303)   //T=u32, pppoe mtu
#define CSID_C_IPV6_PPPOE_IDLETIME 				_CFG_IPV6(0x0304)   //T=u32, pppoe max idle time
#define CSID_C_IPV6_PPPOE_HOLDOFFTIME 			_CFG_IPV6(0x0305)   //T=u32, pppoe wait time before rebuild
#define CSID_C_IPV6_PPPOE_CNT_TYPE				_CFG_IPV6(0x0306)   //T=u32, pppoe connect type, Dial-on-Demand, autoconnect...

/* [6to4] */

/* [IPv6 in IPv4] */
#define CSID_C_IPV6_6IN4_REMOTE_IPV4			_CFG_IPV6(0x0500)   //T=ipv4, remote ipv4 address
#define CSID_C_IPV6_6IN4_REMOTE_IPV6 			_CFG_IPV6(0x0501)	//T=str, remote ipv6 address
#define CSID_C_IPV6_6IN4_LOCAL_IPV4				_CFG_IPV6(0x0502)	//T=ipv4, local ipv4 address
#define CSID_C_IPV6_6IN4_LOCAL_IPV6				_CFG_IPV6(0x0503)	//T=str, local ipv6 address
#define CSID_C_IPV6_6IN4_IF_PRIDNS              _CFG_IPV6(0x0504)   //T=str, pppoe interface Primary DNS
#define CSID_C_IPV6_6IN4_IF_SECDNS              _CFG_IPV6(0x0505)   //T=str, pppoe interface Second DNS

/* [DNS] */
#define CSID_C_IPV6_DHCPC_IF_PRIDNS             _CFG_IPV6(0x0600)   //T=str, interface Primary DNS
#define CSID_C_IPV6_DHCPC_IF_SECDNS             _CFG_IPV6(0x0601)   //T=str, interface Second DNS 
#define CSID_C_IPV6_DHCPC_CONFIG_DNS_MANUALLY   _CFG_IPV6(0x0602)   //T=u32, 0:auto config, 1: manually config

/* [DHCPv6s] */
#define CSID_C_IPV6_DHCPV6S_START_IP			_CFG_IPV6(0x1000) 	//T=str, ipv6 pool start
#define CSID_C_IPV6_DHCPV6S_END_IP              _CFG_IPV6(0x1001) 	//T=str, ipv6 pool end
#define CSID_C_IPV6_DHCPV6S_LIFTTIME			_CFG_IPV6(0x1002) 	//u=32, lift time

/* [radvd] */
#define CSID_C_IPV6_RADVD_LIFTTIME				_CFG_IPV6(0x1100) 	//u=32, lift time

/* Status Items */

#define CSID_S_IPV6_IF_IP              			_STA_IPV6(0x0000)   //T=str, interface ip
#define CSID_S_IPV6_IF_PREFIX_LEN         		_STA_IPV6(0x0001)   //T=u32, prefix
#define CSID_S_IPV6_IF_GW                 		_STA_IPV6(0x0002)   //T=str, interface gateway
#define CSID_S_IPV6_IF_PRIDNS                   _STA_IPV6(0x0003)   //T=str, Primary DNS
#define CSID_S_IPV6_IF_SECDNS                   _STA_IPV6(0x0004)   //T=str, Second DNS 
#define CSID_S_IPV6_MTU                         _STA_IPV6(0x0005)   //T=u32, mtu
#define CSID_S_IPV6_IF_LL_IP                    _STA_IPV6(0x0006)   //T=str, link-local address
#define CSID_S_IPV6_IF_LL_GW_IP                 _STA_IPV6(0x0007)   //T=str, gateway link-local address
#define CSID_S_IPV6_LAN_IF_LL_IP                _STA_IPV6(0x0008)   //T=str, lan link-local address

#define CSID_S_IPV6_ALTERED       				_STA_IPV6(0x0010)   //T=u32, ui altered

/* [pppoe] */
#define CSID_S_IPV6_PPPOE_IF_ID					_STA_IPV6(0x0300)

#endif //ifndef _CSID_IPV6_H

