/*
 * @file Member ID Definition of Group L2TP.
 *
 * Moderator: GeorgeWang
 * Group ID: 0x00060000/0x80060000
 */

#ifndef _CSID_L2TP_H
#define _CSID_L2TP_H

#include "csid_gid.h"

#define _CFG_L2TP(x)		(CSID_GIDC_L2TP|(x))
#define _STA_L2TP(x)		(CSID_GIDS_L2TP|(x))

/* Extra Definitions */
#define L2TP_CNT_TYPE_ONDEMAND			0x00
#define L2TP_CNT_TYPE_AUTORECONNECT		0x01
#define L2TP_CNT_TYPE_MANUAL			0x02

#define L2TP_AUTHTYPE_AUTO				0x00
#define L2TP_AUTHTYPE_PAP				0x01
#define L2TP_AUTHTYPE_CHAP				0x02
#define L2TP_AUTHTYPE_MSCHAP			0x04
#define L2TP_AUTHTYPE_MSCHAPV2			0x08
#define L2TP_AUTHTYPE_EAP				0x10

#define L2TP_PHASE1_DHCP				0x00
#define L2TP_PHASE1_FIXED				0x01

#define L2TP_CNT_STATUS_DISCONNECT		0x00
#define L2TP_CNT_STATUS_CONNECTING		0x01
#define L2TP_CNT_STATUS_CONNECT			0x02
#define L2TP_CNT_STATUS_DISCONNECTING	0x03
#define L2TP_CNT_STATUS_WAIT_TRAFFIC	0x05
#define L2TP_CNT_STATUS_AUTH_FAIL		0x06

#define L2TP_CLI_MAX_TUN        		16

/* Configuration Items for WAN Type L2TP */
#define CSID_C_L2TP_USER					_CFG_L2TP(0x0100)	//T=str, user name
#define CSID_C_L2TP_MULTIWAN_USER           _CFG_L2TP(0x0101)	//T=str, user name
#define CSID_C_L2TP_PASSWORD				_CFG_L2TP(0x0200)	//T=str, user password
#define CSID_C_L2TP_MULTIWAN_PASSWORD       _CFG_L2TP(0x0201)	//T=str, user password
#define CSID_C_L2TP_P1FIXED_IP				_CFG_L2TP(0x0300)	//T=ipv4, fixed interface ip
#define CSID_C_L2TP_MULTIWAN_P1FIXED_IP		_CFG_L2TP(0x0301)	//T=ipv4, fixed interface ip
#define CSID_C_L2TP_P1FIXED_NM				_CFG_L2TP(0x0400)	//T=ipv4, fixed interface netmask
#define CSID_C_L2TP_MULTIWAN_P1FIXED_NM     _CFG_L2TP(0x0401)	//T=ipv4, fixed interface netmask
#define CSID_C_L2TP_P1FIXED_GW				_CFG_L2TP(0x0500)	//T=ipv4, fixed interface gateway
#define CSID_C_L2TP_MULTIWAN_P1FIXED_GW		_CFG_L2TP(0x0501)	//T=ipv4, fixed interface gateway
#define CSID_C_L2TP_LNS_SERVER				_CFG_L2TP(0x0600)	//T=str, LNS server name/ip
#define CSID_C_L2TP_MULTIWAN_LNS_SERVER 	_CFG_L2TP(0x0601)	//T=str, LNS server name/ip
#define CSID_C_L2TP_P1FIXED_PRIDNS			_CFG_L2TP(0x0700)	//T=ipv4, fixed interface primary DNS
#define CSID_C_L2TP_MULTIWAN_P1FIXED_PRIDNS _CFG_L2TP(0x0701)	//T=ipv4, fixed interface primary DNS
#define CSID_C_L2TP_P1FIXED_SECDNS			_CFG_L2TP(0x0800)	//T=ipv4, fixed interface secondary DNS
#define CSID_C_L2TP_MULTIWAN_P1FIXED_SECDNS _CFG_L2TP(0x0801)	//T=ipv4, fixed interface secondary DNS
#define CSID_C_L2TP_CNT_TYPE				_CFG_L2TP(0x0900)	//T=u16, connect type
#define CSID_C_L2TP_MULTIWAN_CNT_TYPE    	_CFG_L2TP(0x0901)	//T=u16, connect type
#define CSID_C_L2TP_MTU						_CFG_L2TP(0x0a00)	//T=u16, D=0,  max transmission unit
#define CSID_C_L2TP_MULTIWAN_MTU           	_CFG_L2TP(0x0a01)	//T=u16, D=0,  max transmission unit
#define CSID_C_L2TP_IDLETIME				_CFG_L2TP(0x0b00)	//T=u16, D=600, max idle time
#define CSID_C_L2TP_MULTIWAN_IDLETIME      	_CFG_L2TP(0x0b01)	//T=u16, D=600, max idle time
#define CSID_C_L2TP_HOLDOFFTIME				_CFG_L2TP(0x0c00)	//T=u16, D=300, wait time before rebuild
#define CSID_C_L2TP_MULTIWAN_HOLDOFFTIME   	_CFG_L2TP(0x0c01)	//T=u16, D=300, wait time before rebuild
#define CSID_C_L2TP_AUTHTYPE				_CFG_L2TP(0x0d00)	//T=u16, auth type
#define CSID_C_L2TP_MULTIWAN_AUTHTYPE      	_CFG_L2TP(0x0d01)	//T=u16, auth type
#define CSID_C_L2TP_PHASE1_TYPE				_CFG_L2TP(0x0e00)	//T=u8, D=0, connect to server in phase1 stage
#define CSID_C_L2TP_MULTIWAN_PHASE1_TYPE   	_CFG_L2TP(0x0e01)	//T=u8, D=0, connect to server in phase1 stage
#define CSID_C_L2TP_PORT					_CFG_L2TP(0x0f00)	//T=u16, D=1702, LNS server port
#define CSID_C_L2TP_MULTIWAN_PORT          	_CFG_L2TP(0x0f01)	//T=u16, D=1702, LNS server port

/* Configuration Items for VPN - L2TP Client */
#define CSID_C_L2TP_CLI_ENABLE          _CFG_L2TP(0x1000)   //T=u8, D=0, enable l2tp client
#define CSID_C_L2TP_CLI_USER_ENABLE     _CFG_L2TP(0x1100)   //T=u8, D=0, enable l2tp client user
#define CSID_C_L2TP_CLI_TUNLNAME        _CFG_L2TP(0x1200)   //T=str, tunnel name
#define CSID_C_L2TP_CLI_PEERIP          _CFG_L2TP(0x1300)   //T=ipv4, peer ip
#define CSID_C_L2TP_CLI_USER            _CFG_L2TP(0x1400)   //T=str, user name
#define CSID_C_L2TP_CLI_PASSWORD        _CFG_L2TP(0x1500)   //T=str, user password
#define CSID_C_L2TP_CLI_ROUTE           _CFG_L2TP(0x1600)   //T=str, route
#define CSID_C_L2TP_CLI_CONNECT_TYPE    _CFG_L2TP(0x1700)   //T=u8, D=0, connect type
#define CSID_C_L2TP_CLI_MPPE            _CFG_L2TP(0x1800)   //T=u8, D=0, enable mppe
#define CSID_C_L2TP_CLI_NAT             _CFG_L2TP(0x1900)   //T=u8, D=0, enable nat

/* Status Items for WAN Type L2TP */
#define CSID_S_L2TP_LNS_SERVER_IP			_STA_L2TP(0x0010)	//T=str, LNS server name/ip
#define CSID_S_L2TP_MULTIWAN_LNS_SERVER_IP  _STA_L2TP(0x0011)	//T=str, LNS server name/ip
#define CSID_S_L2TP_CNT_TIME				_STA_L2TP(0x0100)	//T=u32, connect time
#define CSID_S_L2TP_MULTIWAN_CNT_TIME		_STA_L2TP(0x0101)	//T=u32, connect time
#define CSID_S_L2TP_IF_IP					_STA_L2TP(0x0200)	//T=ipv4, dynamic interface ip
#define CSID_S_L2TP_MULTIWAN_IF_IP			_STA_L2TP(0x0201)	//T=ipv4, dynamic interface ip
#define CSID_S_L2TP_IF_NM					_STA_L2TP(0x0300)	//T=ipv4, dynamic interface netmask
#define CSID_S_L2TP_MULTIWAN_IF_NM			_STA_L2TP(0x0301)	//T=ipv4, dynamic interface netmask
#define CSID_S_L2TP_IF_GW					_STA_L2TP(0x0400)	//T=ipv4, dynamic interface gateway
#define CSID_S_L2TP_MULTIWAN_IF_GW			_STA_L2TP(0x0401)	//T=ipv4, dynamic interface gateway
#define CSID_S_L2TP_IF_PRIDNS				_STA_L2TP(0x0500)	//T=ipv4, dynamic interface primary DNS
#define CSID_S_L2TP_MULTIWAN_IF_PRIDNS		_STA_L2TP(0x0501)	//T=ipv4, dynamic interface primary DNS
#define CSID_S_L2TP_IF_SECDNS				_STA_L2TP(0x0600)	//T=ipv4, dynamic interface secondary DNS
#define CSID_S_L2TP_MULTIWAN_IF_SECDNS		_STA_L2TP(0x0601)	//T=ipv4, dynamic interface secondary DNS
#define CSID_S_L2TP_CNT_STATUS				_STA_L2TP(0x0700)	//T=u16, D=1, connect status
#define CSID_S_L2TP_MULTIWAN_CNT_STATUS		_STA_L2TP(0x0701)	//T=u16, D=1, connect status
#define CSID_S_L2TP_PKTIN_NUM				_STA_L2TP(0x0800)	//T=u32, number of packet input
#define CSID_S_L2TP_MULTIWAN_PKTIN_NUM		_STA_L2TP(0x0801)	//T=u32, number of packet input
#define CSID_S_L2TP_PKTOUT_NUM				_STA_L2TP(0x0900)	//T=u32, number of packet output
#define CSID_S_L2TP_MULTIWAN_PKTOUT_NUM		_STA_L2TP(0x0901)	//T=u32, number of packet output
#define CSID_S_L2TP_ALTERED					_STA_L2TP(0x0a00)	//T=u8, ui altered
#define CSID_S_L2TP_MULTIWAN_ALTERED		_STA_L2TP(0x0a01)	//T=u8, ui altered

/* Status Items for VPN - L2TP Client */
#define CSID_S_L2TP_CLI_ALTERED         _STA_L2TP(0x0011)   //T=u8, D=0, UI Altered
#define CSID_S_L2TP_CLI_PEER_CONNT_ID   _STA_L2TP(0x0012)   //T=u8, D=0, which tunnel try to connect/disconnect 
#define CSID_S_L2TP_CLI_PEER_PID        _STA_L2TP(0x0b00)   //T=u16, D=0, tunnels' pid
#define CSID_S_L2TP_CLI_PEER_VIRTUAL_IP _STA_L2TP(0x0c00)   //T=ipv4, D={0.0.0.0}, virtual IP address assigned from PPP Server
#define CSID_S_L2TP_CLI_PEER_REMOTE_IP  _STA_L2TP(0x0d00)   //T=ipv4, D={0.0.0.0}, virtual IP address of L2TP Server
#define CSID_S_L2TP_CLI_PEER_IFNAME     _STA_L2TP(0x0e00)   //T=str, interface name
#define CSID_S_L2TP_CLI_PEER_ALTERED    _STA_L2TP(0x0f00)   //T=u8, D=0, tunnel's configuration altered

#endif //ifndef _CSID_L2TP_H
