/* dhcpp.c
 *
 * udhcp DHCP probe
 *
 */
 
 
#include <stdio.h>
#include <sys/time.h>
#include <sys/types.h>
#include <sys/file.h>
#include <unistd.h>
#include <getopt.h>
#include <stdlib.h>
#include <sys/socket.h>
#include <netinet/in.h>
#include <arpa/inet.h>
#include <signal.h>
#include <time.h>
#include <string.h>
#include <sys/ioctl.h>
#include <net/if.h>
#include <errno.h>

#include "dhcpd.h"
#include "dhcpp.h"
#include "options.h"
#include "probepacket.h"
#include "packet.h"
#include "script.h"
#include "socket.h"
#include "debug.h"

//static unsigned long server_addr;
static int fd = -1;
static int signal_pipe[2];
static unsigned long requested_ip; /* = 0 */

struct probe_config_t probe_config = {
    /* Default options. */
    clientid: NULL,
    hostname: NULL,
    timeout: 3,
    interface: "ixp0",
    ifindex: 0,
    arp: "\0\0\0\0\0\0",		/* appease gcc-3.0 */
};


/* Signal handler */
static void signal_handler(int sig)
{
    if (send(signal_pipe[1], &sig, sizeof(sig), MSG_DONTWAIT) < 0) {
        LOG(LOG_ERR, "Could not send signal: %s",
            strerror(errno));
    }
}
/* Exit and cleanup */
static void exit_probe(int retval)
{
    CLOSE_LOG();
    exit(retval);
}
/*
static int max_of_two(int w, int x)
{
    int max = w;

    if (x > max)
        max = x;
    return max;
}
*/
int main(int argc, char *argv[])
{
	int server=0;
	struct timeval tv;
	//struct dhcpMessage packet;
	struct udp_dhcp_packet *dhcp_packet;
	//fd_set rfds;
	//int max_fd;
	unsigned long xid = 0;
	//unsigned char *temp,*message;
	int ret;
	//struct in_addr server;
	int c, sock;
	time_t now,start;	
	int file;

	fd_set readfds;
	char buffer[2048];

	static struct option arg_options[] = {
        	{"interface",	required_argument,	0, 'i'},
        	{"timeout",	required_argument,	0, 't'},
        	{0, 0, 0, 0}
    	};
	
	while (1) {
		int option_index = 0;
        	c = getopt_long(argc, argv, "i:t:", arg_options, 
                        	&option_index);
        	if (c == -1) break;
        	
        	switch (c){
        		case 'i':
            			probe_config.interface =  optarg;
            			break;
            		case 't':
            			probe_config.timeout = atoi(optarg);
            			break;
            		default:
            			break;
        	}
	}	
            					
	
	//printf(" interface = %s  timeout = %d\n", probe_config.interface, probe_config.timeout);
	
	
	OPEN_LOG("udhcpp");
    	LOG(LOG_INFO, "udhcp probe (v%s) started", VERSION);
    
    
    	if (read_interface(probe_config.interface, &probe_config.ifindex, 
                       NULL, probe_config.arp) < 0){
        	exit_probe(1);	
		goto out;
	}
	
	if (!probe_config.clientid) {
        probe_config.clientid = xmalloc(6 + 3);
        probe_config.clientid[OPT_CODE] = DHCP_CLIENT_ID;
        probe_config.clientid[OPT_LEN] = 7;
        probe_config.clientid[OPT_DATA] = 1;
        memcpy(probe_config.clientid + 3, probe_config.arp, 6);
    	}
  	
	/* setup signal handlers */
    	socketpair(AF_UNIX, SOCK_STREAM, 0, signal_pipe);
    	signal(SIGUSR1, signal_handler);
    	signal(SIGUSR2, signal_handler);
    	signal(SIGTERM, signal_handler);
	
	if(1){
		#include <net/ethernet.h>
		#include <netinet/ether.h>
		//int sock;
		char IF[32]="eth2.2";
		struct ifreq ethreq;
		//fd_set readfds;

		if ( (sock=socket(PF_PACKET, SOCK_RAW,
                    htons(ETH_P_ALL)))<0) {
    			perror("socket");
    			goto out;
  		}

 	 	/* Set the network card in promiscuos mode */
 		strncpy(ethreq.ifr_name, IF, IFNAMSIZ);
	  	if (ioctl(sock,SIOCGIFFLAGS,&ethreq)==-1) {
    			perror("ioctl");
    			close(sock);
    			goto out;
  		}
  		ethreq.ifr_flags|=IFF_PROMISC;
  		if (ioctl(sock,SIOCSIFFLAGS,&ethreq)==-1) {
    			perror("ioctl");
    			close(sock);
    			goto out;
  		}
		
	}


	start=time(0);
	//printf("time: %d\n", probe_config.timeout);
	memset(&tv, 0, sizeof(tv));

        if(fd<0){
           fd = raw_socket(probe_config.ifindex);

                        if (fd < 0) {
                                LOG(LOG_ERR, "FATAL: couldn't listen on socket, %s",
                                                strerror(errno));
                                exit_probe(0);
                        }
                        // send the discover packet out 
                        xid=random_xid();
                        send_discover(xid, requested_ip);
        }

	for(;;){
		now=time(0);
		tv.tv_sec=probe_config.timeout - (now - start);
		tv.tv_usec=0;		
		//printf("time: %d\n", tv.tv_sec);

		//printf("-------------\n");
		
        	FD_ZERO(&readfds);
        	FD_SET(sock,&readfds);

        	ret = select(sock+1,&readfds,NULL,NULL, &tv);
		
		if(ret == 0){
			printf("time out\n");
			file=open("/var/run/eth_conf.log",O_WRONLY|O_CREAT);
			write(file,"0", sizeof("0"));
			close(file);
			return 0;
		}

        	if(FD_ISSET(sock,&readfds)){
			int n;
			n = recvfrom(sock,buffer,2048,0,NULL,NULL);
			(unsigned char*)dhcp_packet = buffer + 14;
				
			//if(n>300){
			//	printf("xid:%x\n", dhcp_packet->data.xid);
			//}
			if(dhcp_packet->data.xid == xid){
				//printf("There is a DHCP server here.\n");
	                        
				if (dhcp_packet->data.options[2] == DHCPOFFER){
					server ++;
                                        printf("server:%d\n", server);
					file=open("/var/run/eth_conf.log",O_WRONLY|O_CREAT);
					write(file,"1", sizeof("1"));
					close(file);
					return 1;
                                }

                        }
		}

	}
out:
	file=open("/var/run/eth_conf.log",O_WRONLY|O_CREAT);
	write(file,"0", sizeof("0"));
	close(file);
	return 0;
		
}        
