/* dhcpp.c
 *
 * udhcp DHCP probe
 *
 */
 
 
#include <stdio.h>
#include <sys/time.h>
#include <sys/types.h>
#include <sys/file.h>
#include <unistd.h>
#include <getopt.h>
#include <stdlib.h>
#include <sys/socket.h>
#include <netinet/in.h>
#include <arpa/inet.h>
#include <signal.h>
#include <time.h>
#include <string.h>
#include <sys/ioctl.h>
#include <net/if.h>
#include <errno.h>

#include "dhcpd.h"
#include "dhcpp.h"
#include "options.h"
#include "probepacket.h"
#include "packet.h"
#include "script.h"
#include "socket.h"
#include "debug.h"

//static unsigned long server_addr;
static int fd = -1;
static int signal_pipe[2];
static unsigned long requested_ip; /* = 0 */

struct probe_config_t probe_config = {
    /* Default options. */
    clientid: NULL,
    hostname: NULL,
    timeout: 3,
    interface: "ixp0",
    ifindex: 0,
    arp: "\0\0\0\0\0\0",		/* appease gcc-3.0 */
};


/* Signal handler */
static void signal_handler(int sig)
{
    if (send(signal_pipe[1], &sig, sizeof(sig), MSG_DONTWAIT) < 0) {
        LOG(LOG_ERR, "Could not send signal: %s",
            strerror(errno));
    }
}
/* Exit and cleanup */
static void exit_probe(int retval)
{
    CLOSE_LOG();
    exit(retval);
}

static int max_of_two(int w, int x)
{
    int max = w;

    if (x > max)
        max = x;
    return max;
}

int main(int argc, char *argv[])
{
	int server=0;
	struct timeval tv;
	struct dhcpMessage packet;
	fd_set rfds;
	int max_fd;
	unsigned long xid = 0;
	unsigned char *temp,*message;
	int len, retval;
	//struct in_addr server;
	int c;
	time_t now,start;	
	static struct option arg_options[] = {
        	{"interface",	required_argument,	0, 'i'},
        	{"timeout",	required_argument,	0, 't'},
        	{0, 0, 0, 0}
    	};
	
	while (1) {
		int option_index = 0;
        	c = getopt_long(argc, argv, "i:t:", arg_options, 
                        	&option_index);
        	if (c == -1) break;
        	
        	switch (c){
        		case 'i':
            			probe_config.interface =  optarg;
            			break;
            		case 't':
            			probe_config.timeout = atoi(optarg);
            			break;
            		default:
            			break;
        	}
	}	
            					
	
	//printf(" interface = %s  timeout = %d\n", probe_config.interface, probe_config.timeout);
	
	
	OPEN_LOG("udhcpp");
    	LOG(LOG_INFO, "udhcp probe (v%s) started", VERSION);
    
    
    	if (read_interface(probe_config.interface, &probe_config.ifindex, 
                       NULL, probe_config.arp) < 0)
        	exit_probe(1);
	
	if (!probe_config.clientid) {
        probe_config.clientid = xmalloc(6 + 3);
        probe_config.clientid[OPT_CODE] = DHCP_CLIENT_ID;
        probe_config.clientid[OPT_LEN] = 7;
        probe_config.clientid[OPT_DATA] = 1;
        memcpy(probe_config.clientid + 3, probe_config.arp, 6);
    	}
  	
	/* setup signal handlers */
    	socketpair(AF_UNIX, SOCK_STREAM, 0, signal_pipe);
    	signal(SIGUSR1, signal_handler);
    	signal(SIGUSR2, signal_handler);
    	signal(SIGTERM, signal_handler);
	
	start=time(0);
	for(;;){
		now=time(0);
		tv.tv_sec=probe_config.timeout-(now-start);
		tv.tv_usec=0;
		
		FD_ZERO(&rfds);
		
		if(fd<0) {
			fd = raw_socket(probe_config.ifindex);

		 	if (fd < 0) {
                		LOG(LOG_ERR, "FATAL: couldn't listen on socket, %s", 
                				strerror(errno));
                		exit_probe(0);
            		}	
            		/* send the discover packet out */
			xid=random_xid();
			send_discover(xid, requested_ip);
		}
				
		FD_SET(fd, &rfds);
		FD_SET(signal_pipe[0], &rfds);
	
		max_fd=max_of_two(fd,signal_pipe[0])+1;
		retval=select(max_fd, &rfds, NULL, NULL, &tv);
		
		if(retval==0){
			LOG(LOG_INFO, "udhcpp timeout.");
			exit_probe(server);
		}else if(retval<0) {
			LOG(LOG_ERR, "udhcpp select error."); 
                	exit_probe(0);
		}
		
		if(retval>0 && FD_ISSET(fd, &rfds)){
						
			len = get_raw_packet(&packet, fd);
			if(len==-1 && errno != EINTR) {
				close(fd);
				fd=-1;
			}
			if(len<0){			
				goto out;
			}
			if(packet.xid!=xid){
				goto out;
			}
			if ((message = get_option(&packet, DHCP_MESSAGE_TYPE)) == NULL){ 
				goto out;	
			}	
			if (*message == DHCPOFFER) {
                		if ((temp = get_option(&packet, DHCP_SERVER_ID))) {
                        		//memcpy(&server_addr, temp, 4);
                        		server++;
					//server.s_addr=(in_addr_t)server_addr;
                        		//printf(" server ip =%s\n", inet_ntoa(server));
                        		//printf(" server ip =%08x\n", server_addr);
					//exit_probe(0);
                        	}
                        		
            		}
            				
		}
	out:
		;	
	}
		
	exit_probe(0);
    
}        
